### Batoms

<img src="docs/source/_static/b-c2h6so.png" align="right" width="200"/>

Batoms is a Python package for editing and rendering atoms and molecules objects using blender. A Python interface that allows for automating workflows.

Features:

* Model: space-filling, ball-stick, polyhedral, cavity and so on.
* File type: cif, xyz, cube, pdb, json, VASP-out and so on.
* Volumetric data (Isosurface)
* Animation
* GUI
* ``Flexible``: Python script, run interactively or in background.
* ``High quality rendering``:  3D models
* ``Free, Open Source``: Easy to download and install.
* ``Cross-platform``: (Linux, Windows, macOS)



### Author
* Xing Wang  <xingwang1991@gmail.com>

### Dependencies

* Python
* Blender
* ASE
* Scikit-image


### How to use

Please vist: https://batoms.readthedocs.io/en/latest/
